{# The :autogenerated: tag is picked up by breadcrumbs.html to suppress "Edit on Github" link #}
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

{{ fullname }} package
{% for item in range(8 + fullname|length) -%}={%- endfor %}

.. automodule:: {{ fullname }}
    :members:
    :undoc-members:
    :show-inheritance:

{% if subpackages %}
***********
Subpackages
***********

    .. toctree::
       :maxdepth: 1
{% for item in subpackages %}
       {{ fullname }}.{{ item }}
       {%- endfor %}
    {%- endif %}

{% if submodules %}
**********
Submodules
**********

    .. toctree::
       :maxdepth: 1
{% for item in submodules %}
       {{ fullname }}.{{ item }}
       {%- endfor %}
{%- endif -%}
